import { forwardRef, Module } from '@nestjs/common';
import { PassportModule } from '@nestjs/passport';
import { TypeOrmModule } from '@nestjs/typeorm';
import { MultaController } from './multa.controller';
import { MultaService } from './multa.service';
import { Multa } from './entity/multa.entity';
import { FullInformacionMultaView } from './entity/views/full-informacion-multa.view';
import { InformacionMultaView } from './entity/views/informacion-multa.view';
import { EquipoModule } from '../equipo/equipo.module';
import { InstitucionInfraccionModule } from '../institucion-infraccion/institucion-infraccion.module';
import { InstitucionUsuarioModule } from '../institucion-usuario/institucion-usuario.module';
import { OperadorModule } from '../operador/operador.module';
import { PrestamoModule } from '../prestamo/prestamo.module';
import { UsuarioModule } from '../usuario/usuario.module';

@Module({
  imports: [
    EquipoModule,
    InstitucionInfraccionModule,
    InstitucionUsuarioModule,
    OperadorModule,
    PassportModule.register({ defaultStrategy: 'jwt' }),
    forwardRef(() => PrestamoModule),
    TypeOrmModule.forFeature([
      Multa,
      FullInformacionMultaView,
      InformacionMultaView,
    ]),
    UsuarioModule,
  ],
  controllers: [MultaController],
  providers: [MultaService],
  exports: [MultaService],
})
export class MultaModule {}
